==> python_lectio_unbloated-2.1.19-py3-none-any.whl: lectio/_utils.py <==
from .imports import *


def generatePayload(soup, eventTarget):
    payload = {}
    for _input in soup.find("form", {"id": "aspnetForm"}).find_all(
        "input", {"type": "hidden"}
    ):
        id = _input.get("name")
        if id is None:
            id = _input.get("id")
        payload[id] = _input.get("value")
        if payload[id] is None:
            payload[id] = ""
    payload["__EVENTTARGET"] = eventTarget

    return payload


statusDictionary = {
    "s2brik": "normal",
    "s2cancelled": "aflyst",
    "s2changed": "ændret",
    "s2bgboxeksamen": "eksamen",
}

renameDictionary = {"Lærere": "Lærer", "Lokaler": "Lokale"}


def skemaBrikExtract(dato, skemabrik):
    try:
        absid = (
            re.search("absid=[0-9]+", skemabrik["href"]).group().replace("absid=", "")
        )
    except Exception:
        absid = skemabrik.get("href")

    modulDict = {
        "navn": None,
        "tidspunkt": None,
        "hold": None,
        "hold_id": None,
        "lærer": None,
        "lokale": None,
        "status": "normal",
        "absid": absid,
        "andet": None,
    }

    modulDetaljer = skemabrik
    statusClass = modulDetaljer.get("class")[2]
    if statusClass in statusDictionary:
        modulDict["status"] = statusDictionary[modulDetaljer.get("class")[2]]
    else:
        modulDict["status"] = modulDetaljer.get("class")[2]

    modulDetaljer = modulDetaljer["data-additionalinfo"].split("\n\n")[0].split("\n")

    for modulDetalje in modulDetaljer:
        if (value := ": ".join(modulDetalje.split(": ")[1:])) != "":
            if (navn := modulDetalje.split(": ")[0]) in renameDictionary:
                navn = renameDictionary[navn]

            modulDict[navn.lower()] = value
        elif re.search(
            r"((?:[1-9]|[12][0-9]|3[01])\/(?:[1-9]|1[012])-(?:19|20)\d\d) ((?:[01]?[0-9]|2[0-3]):(?:[0-5][0-9])) til ((?:[01]?[0-9]|2[0-3]):(?:[0-5][0-9]))",
            modulDetalje,
        ):
            modulDict["tidspunkt"] = modulDetalje
        else:
            modulDict["navn"] = modulDetalje

    try:
        modulDict["hold_id"] = (
            re.search('data-lectiocontextcard="HE[0-9]+', str(skemabrik))
            .group()
            .replace('data-lectiocontextcard="', "")
        )
    except Exception:
        pass

    try:
        modulDict["andet"] = skemabrik["data-additionalinfo"].split("\n\n")[1]
    except Exception:
        pass

    return modulDict

==> python_lectio_unbloated-2.1.23-py3-none-any.whl: lectio/_utils.py <==
from .imports import *


def generatePayload(soup, eventTarget):
    payload = {}
    for _input in soup.find("form", {"id": "aspnetForm"}).find_all(
        "input", {"type": "hidden"}
    ):
        id = _input.get("name")
        if id is None:
            id = _input.get("id")
        payload[id] = _input.get("value")
        if payload[id] is None:
            payload[id] = ""
    payload["__EVENTTARGET"] = eventTarget

    return payload


statusDictionary = {
    "s2brik": "normal",
    "s2cancelled": "aflyst",
    "s2changed": "ændret",
    "s2bgboxeksamen": "eksamen",
}

renameDictionary = {"Lærere": "Lærer", "Lokaler": "Lokale"}


def skemaBrikExtract(skemabrik):
    try:
        absid = (
            re.search("absid=[0-9]+", skemabrik["href"]).group().replace("absid=", "")
        )
    except Exception:
        absid = skemabrik.get("href")

    modulDict = {
        "navn": None,
        "tidspunkt": None,
        "hold": None,
        "hold_id": None,
        "lærer": None,
        "lokale": None,
        "status": "normal",
        "absid": absid,
        "andet": None,
    }

    modulDetaljer = skemabrik
    statusClass = modulDetaljer.get("class")[2]
    if statusClass in statusDictionary:
        modulDict["status"] = statusDictionary[modulDetaljer.get("class")[2]]
    else:
        modulDict["status"] = modulDetaljer.get("class")[2]

    modulDetaljer = modulDetaljer["data-additionalinfo"].split("\n\n")[0].split("\n")

    for modulDetalje in modulDetaljer:
        if (value := ": ".join(modulDetalje.split(": ")[1:])) != "":
            if (navn := modulDetalje.split(": ")[0]) in renameDictionary:
                navn = renameDictionary[navn]

            modulDict[navn.lower()] = value
        elif re.search(
            r"((?:[1-9]|[12][0-9]|3[01])\/(?:[1-9]|1[012])-(?:19|20)\d\d) ((?:[01]?[0-9]|2[0-3]):(?:[0-5][0-9])) til ((?:[01]?[0-9]|2[0-3]):(?:[0-5][0-9]))",
            modulDetalje,
        ):
            modulDict["tidspunkt"] = modulDetalje
        else:
            modulDict["navn"] = modulDetalje

    try:
        modulDict["hold_id"] = (
            re.search('data-lectiocontextcard="HE[0-9]+', str(skemabrik))
            .group()
            .replace('data-lectiocontextcard="', "")
        )
    except Exception:
        pass

    try:
        modulDict["andet"] = skemabrik["data-additionalinfo"].split("\n\n")[1]
    except Exception:
        pass

    return modulDict
